// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KDECORATION2_VERSION_H
#define KDECORATION2_VERSION_H

#define KDECORATION2_VERSION_STRING "5.27.12"
#define KDECORATION2_VERSION_MAJOR 5
#define KDECORATION2_VERSION_MINOR 27
#define KDECORATION2_VERSION_PATCH 12
#define KDECORATION2_VERSION ((5<<16)|(27<<8)|(12))

#endif
